@@ -10,12 +10,12 @@ logger.addHandler(log_hndl)
 logger.setLevel("INFO")
 
 
-__version__ = "0.9.0"
+__version__ = "0.10.0"
 
 __tasks__ = {}
 
 
 from arrlio.core import App, logger, task  # noqa
 from arrlio.exc import NotFoundError, TaskError, TaskNoResultError, TaskTimeoutError  # noqa
-from arrlio.models import Graph  # noqa
+from arrlio.models import Graph, Result  # noqa
 from arrlio.settings import Config  # noqa
