@@ -15,6 +15,7 @@ from arrlio import core
 from arrlio.backends import base
 from arrlio.exc import TaskNoResultError
 from arrlio.models import Event, Message, TaskInstance, TaskResult
+from arrlio.settings import ENV_PREFIX
 from arrlio.tp import AsyncCallableT, ExceptionFilterT, PositiveIntT, PriorityT, RMQDsn, SerializerT, TimeoutT
 from arrlio.utils import retry
 
@@ -60,7 +61,7 @@ class BackendConfig(base.BackendConfig):
 
     class Config:
         validate_assignment = True
-        env_prefix = "ARRLIO_RMQ_BACKEND_"
+        env_prefix = f"{ENV_PREFIX}RMQ_BACKEND_"
 
 
 class RMQConnection:
