@@ -1,6 +1,6 @@
 from typing import Any
 
-from arrlio.models import TaskInstance, TaskResult
+from arrlio.models import Event, TaskInstance, TaskResult
 from arrlio.serializer import base
 
 
@@ -17,6 +17,12 @@ class Nop(base.Serializer):
     def loads_task_result(self, data: TaskResult) -> TaskResult:
         return data
 
+    def dumps_event(self, event: Event, **kwds) -> Event:
+        return event
+
+    def loads_event(self, data: Event) -> Event:
+        return data
+
     def dumps(self, data: Any, **kwds) -> Any:
         return data
 
