@@ -49,7 +49,7 @@ def retry(retry_timeouts: Iterable[int] = None, exc_filter: ExceptionFilterT = N
                         raise e
                     try:
                         t = next(retry_timeouts)
-                        logger.error("%s - retry in %s second(s)", e, t)
+                        logger.error("%s %s - retry in %s second(s)", e.__class__, e, t)
                         await asyncio.sleep(t)
                     except StopIteration:
                         raise e
